SCUBA
[![Build Status](https://github.com/JonathonReinhart/scuba/actions/workflows/build-test.yml/badge.svg)](https://github.com/JonathonReinhart/scuba/actions/workflows/build-test.yml)
[![codecov.io](https://codecov.io/github/JonathonReinhart/scuba/coverage.svg?branch=main)](https://codecov.io/github/JonathonReinhart/scuba?branch=main)
[![PyPI](https://img.shields.io/pypi/v/scuba.svg)](https://pypi.python.org/pypi/scuba)
[![Docs](https://readthedocs.org/projects/scuba/badge/?version=latest)](https://scuba.readthedocs.io/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
-----
![SCUBA](docs/images/SCUBA.png)

**SCUBA** is the **S**imple **C**ontainer-**U**tilizing **B**uild **A**pparatus

Scuba makes it easier to use Docker containers in everyday development. It
allows a developer to commit an environment setup where the entire build
environment is encapsulated in a Docker container.

![demo](docs/images/demo.gif)

For more information, [Read the Docs](https://scuba.readthedocs.io/).

## License

This software is released under the [MIT License](https://opensource.org/licenses/MIT).
